﻿using System;
using System.Runtime.InteropServices;    // For StructLayout, DllImport

namespace WhaleTeqSECG_SDK
{
    public enum OutputFunction
    {
        Output_Off  = 0,
        Output_Sine,
        Output_Triangle,
        Output_Square,
        Output_RectanglePulse,
        Output_TrianglePulse,
        Output_Exponential,
        Output_ECG2_27,
        Output_IEC227W,
        Output_IEC251W,
        Output_JJG1041,
        Output_JJG1041_HR,
        Output_JJG_Hysteresis,
        Output_ECG_File,
        Output_InputDynamicRange
    };

    public enum PacingPulse_E
    {
        SinglePulse = 0,
        DoublePulse_150ms,
        DoublePulse_250ms
    };

    public enum OutputLead_E 
    {
		Lead_RA		= 0,	//(R)
		Lead_LA,			//(L)
		Lead_LL,			//(F)
		Lead_V1,
		Lead_V2,
		Lead_V3,
		Lead_V4,
		Lead_V5,
		Lead_V6
	};

    public enum BaselineReset_E 
    {
		Baseline_Off	= 0,
		Baseline_50Hz,
		Baseline_60Hz,
		Baseline_80Hz,
		Baseline_100Hz
	};

    public enum ECG2_27_NoiseFreq_E 
    {
		Noise_None	= 0,
		Noise_50Hz,
		Noise_60Hz
	};

    public enum SpecialWave227
    {
        IEC227W_3A_A1 = 0,
        IEC227W_3B_A2,
        IEC227W_3C_A3,
        IEC227W_3D_A4,
        IEC227W_4A_B1,
        IEC227W_4A_B1x2,
        IEC227W_4A_B1d2,
        IEC227W_4B_B2,
        IEC227W_4B_B2x2,
        IEC227W_4B_B2d2,

    };
    public enum SpecialWave251
    {
        IEC251W_1 = 0,	//CAL05000
        IEC251W_2,		//CAL10000
        IEC251W_3,		//CAL15000
        IEC251W_4,		//CAL20000
        IEC251W_6,		//CAL30000
        IEC251W_10,		//CAL50000
        CAL20002,		//--------- New Added ------------------------
        CAL20100,
        CAL20110,
        CAL20160,
        CAL20200,
        CAL20210,
        CAL20260,
        CAL20500,
        CAL20502,
        CAL40000
    };

   

    class SECG_SDK
    {
        private const string DllFilePath = "SECG40x86.dll";

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.LPStr)]
        public static extern string GetSDKVersion();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern void RegistConnectCB(IntPtr cb);
        //Parameter - cb:
        //  function pointer of delegate from "Marshal.GetFunctionPointerForDelegate(delegate)"
        //      delegate void ConnectCBDelegate(bool connected);
        //      Parameter - connected
        //	        true: SECG is Connected
        //	        false: SECG is Unconnected

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern void SpecifyCOMPort(int portNum);

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool InitSECG();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern void ResetSECG();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern void ResetSECG_AllLeadOff();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern void CloseSECG();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool IsConnected();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool TriggerDeviceChanged();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern IntPtr GetUSBPort();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.LPStr)]
        public static extern string GetSerialNo();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern IntPtr GetHWInfo();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern IntPtr GetFWVersion();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern IntPtr GetHWVersion();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern IntPtr GetLicenseKey();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern void WriteLicenseKey(ref byte[] key, int len, int offset);

        //3rd Party License
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool CheckoutLicenseFeature1();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool CheckoutLicenseFeature2();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool CheckoutLicenseFeature3();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern IntPtr GetHardwareID();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool ActiveLicenseKey(string key);

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int GetAD();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern void RegisterTimeAmpCB(IntPtr cb);
        //Parameter - cb:
        //  function pointer of delegate from "Marshal.GetFunctionPointerForDelegate(delegate)"
        //      delegate void TimeAmplitudeCBDelegate(double time, double amp);
        //      Parameter - time
        //	        unit: second
        //	        time from the output signal changed(function, amplitude, frequency ...)
        //      Parameter - amp
        //	        unit: millivolt
        //About 0.006 second(6ms) interval between each callback be triggered

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern void RegisterPacingTimeAmpCB(IntPtr cb);

         //Return value:
        // 0:  succeed
        // -1: Mainfunction not set to IEC227W
        // Call after set main func to Output_IEC227w
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetSpecialWave227(SpecialWave227 spec);
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern SpecialWave227 GetSpecialWave227();
        //Return value:
        // 0:  succeed
        // -1: Mainfunction not set to IEC251W
        // Call after set main func to Output_IEC251w
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetSpecialWave251(SpecialWave251 spec);
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern SpecialWave251 GetSpecialWave251();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetOutputFunc(OutputFunction func);
        //Return value:
        //	0:	succeed
        //	-1:	SECG not be initialized
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern OutputFunction GetOutputFunc();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetAmplitude(double amp);
        //Parameter - amp:
        //	value range: -10 ~ 10
        //	unit: millivolt
        //Return value:
        //	0: succeed
        //	-1: SECG not be initialized
        //	-2: value out of range
        //  -3: "Baseline Reset Test" is working
        //Default value after InitSECG(): 1mV
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetAmplitude();
        public const double DefaultAmplitude = 1.0;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetFrequency(double freq);
        //Parameter - freq:
        //	value range: 0.05 ~ 5, if Output is Pulse Waveforms
        //               0.05 ~ 3, if Output is Exponential
        //               0.05 ~ 6, if Output is ECG2_27
        //               0.05 ~ 500, others
        //	unit: hertz
        //Return value:
        //	0: succeed
        //	-1: SECG not be initialized
        //	-2: value out of range
        //	-3: "Frequency Scan" is working
        //  -4: "Baseline Reset Test" is working
        //Default value after InitSECG(): 1Hz
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetFrequency();
        public const double DefaultFrequency = 1.0;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetDCOffset(int setting);
        //Parameter - setting:
        //	value range: -300 ~ 300 - DCOffset Variable mode Off
        //               -1000 ~ 1000 - DCOffset Variable mode On
        //	unit: millivolt(mV)
        //Return value:
        //	0: succeed
        //	-1: SECG not be initialized
        //	-2: value out of range
        //Default value after InitSECG(): 0mV
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int GetDCOffset();
        public const int DefaultDCOffset = 0;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetDCOffsetVariableMode(bool OnOff);
        //Return value:
        //	0: succeed
        //	-1: SECG not be initialized
        //Default value after InitSECG(): false(Off)
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool GetDCOffsetVariableMode();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetDCOffsetCommonMode(bool OnOff);

        [DllImport (DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetDCOffsetCommoneMode(bool OnOff); //For backward compatical the typo
        //Return value:
        //	0: succeed
        //	-1: SECG not be initialized
        //Default value after InitSECG(): false(Off)
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool GetDCOffsetCommonMode();

        [DllImport (DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs (UnmanagedType.I1)]
        public static extern bool GetDCOffsetCommoneMode(); //For backward compatical the typo

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetPulseWidth(double width);
        //Parameter - width:
        //	value range: 2 ~ 300
        //	unit: milisecond(ms)
        //Return value:
        //	0: succeed
        //	-1: SECG not be initialized
        //	-2: value out of range
        //Default value after InitSECG(): 100ms
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetPulseWidth();
        public const double DefaultPulseWidth = 100;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetInputImpedanceMode(bool OnOff);
        //Return value:
        //	0: succeed
        //	-1: SECG not be initialized
        //Default value after InitSECG(): true(On - 620k&/4.7nF shorted)
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool GetInputImpedanceMode();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetPacingPulseMode(PacingPulse_E mode);
        //Return value:
        //	0:	succeed
        //	-1:	SECG not be initialized
        //Default value after InitSECG(): SinglePulse
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern PacingPulse_E GetPacingPulseMode();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetQRSDuration(double time);
        //Parameter - time:
	    //	value range: 5 ~ 200
	    //	unit: milisecond(ms)
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
	    //	-2: value out of range
	    //Default value after InitSECG(): 100ms
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetQRSDuration();
        public const double DefaultQRSDuration = 100.0;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetTWave(double amp);
	    //Parameter - amp:
	    //	value range: 0 ~ 2.5
	    //	unit: millivolt(mV)
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
	    //	-2: value out of range
	    //Default value after InitSECG(): 0.2mV
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetTWave();
        public const double DefaultTWave = 0.2;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetPacingAmplitude(double amp);
	    //Parameter - amp:
	    //	value range: -700 ~ 700
	    //	unit: millivolt(mV)
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
	    //	-2: value out of range
	    //Default value after InitSECG(): 0mV
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetPacingAmplitude();
        public const double DefaultPacingAmplitude = 0;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetPacingDuration(double time);
	    //Parameter - time:
	    //	value range: 0.1 ~ 3
	    //	unit: milisecond(ms)
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
	    //	-2: value out of range
	    //Default value after InitSECG(): 2ms
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetPacingDuration();
        public const double DefaultPacingDuration = 2.0;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetPacingRate(uint BPM);
	    //Parameter - BPM:
	    //	value range: 10 ~ 300
	    //	unit: beats per minute(BPM)
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
	    //	-2: value out of range
	    //Default value after InitSECG(): 60BPM
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern uint GetPacingRate();
        public const int DefaultPacingRate = 60;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetOvershootTimeConstant(uint time);
	    //Parameter - time:
	    //	value range: 0 ~ 100
	    //	unit: milisecond(ms)
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
	    //	-2: value out of range
	    //Default value after InitSECG(): 0ms
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern uint GetOvershootTimeConstant();
        public const uint DefaultOvershootTimeConstant = 0;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int SetPacingOvershootAmp(double amp);
        //Parameter - amp:
        //	value range: -2 ~ 2
        //	unit: millivolt(mV)
        //Return value:
        //	0: succeed
        //	-1: SECG not be initialized
        //	-2: value out of range
        //Default value after InitSECG(): 0mV -> Auto set to -0.25 * Pacing Amplitude
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetPacingOvershootAmp();
        public const double DefaultPacingOvershootAmp = 0;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetOutputLead(OutputLead_E lead, bool OnOff);
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
	    //Default value after InitSECG(): Lead_RA - On; all others - Off;
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool GetOutputLead(OutputLead_E lead);

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern void RegisterSyncFreqCB(IntPtr cb);
        //Parameter - cb:
        //  function pointer of delegate from "Marshal.GetFunctionPointerForDelegate(delegate)"
        //      delegate void SyncFreqCBDelegate(double freq);
        //      Parameter - freq
        //	        unit: hertz
        //	        frequency value changed during "Baseline Reset Test" or "Frequency Scanning"


        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetBaselineResetTest(BaselineReset_E mode);        	
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
	    //	-2: current main output function not be "Output_Sine"
	    //Default value after InitSECG(): Baseline_Off
	    //"Output Function" must be set to "Output_Sine" before setting as "non - Baseline_Off" value
	    //After setting as "non - Baseline_Off" value, "Amplitude" would be locked to "2.5mV"
	    //and "Frequency" would be locked as "50/60/80/100" Hz.
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern BaselineReset_E GetBaselineResetTest();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetECG2_27_Noise(ECG2_27_NoiseFreq_E freq, double amp);
	    //Parameter - freq:
	    //	Default value after InitSECG(): Noise_None
	    //Parameter - amp:
	    //	value range: 0.01 ~ 10
	    //	unit: millvolt(mV)
	    //	Default value after InitSECG(): 0.1mV
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
        //	-2: current main output function not be "Output_ECG2_27"
	    //	-3: amp out of range
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern ECG2_27_NoiseFreq_E SetECG2_27_Noise();
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetECG2_27_NoiseAmp();
        public const double DefaultECG2_27_NoiseAmp = 0.1;

        //Parameter - enableDriftTest
	    //    true, enable AAMI EC 13 Drift test; adds 4mVpp 0.1Hz triangle waveform to the ECG signal 
	    //    false, disable AAMI EC 13 Drift test
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetECG2_27_AAMIDriftTest (bool enableDriftTest);
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool GetECG2_27_AAMIDriftTest();

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetDynamicRangeTest(bool OnOff, double amp, double freq);
        //Parameter - amp:
	    //	value range: 0 ~ 5
	    //	unit: millivolt(mV)
	    //	Default value after InitSECG(): 1mV
	    //Parameter - freq:
	    //	value range: 10 ~ 50
	    //	unit: hertz
	    //	Default value after InitSECG(): 40Hz
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
        //	-2: current main output function not be "Output_Square"
	    //	-3: amp out of range
	    //	-4: freq out of range
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool GetDynamicRangeTest(bool OnOff);
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetDynamicRangeTestAmp();
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetDynamicRangeTestFreq();
        public const double DefaultDynamicRangeTestAmp = 1.0;
        public const double DefaultDynamicRangeTestFreq = 40;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern void RegisterSyncMainFuncCB(IntPtr cb);
        //Parameter - cb:
        //  function pointer of delegate from "Marshal.GetFunctionPointerForDelegate(delegate)"
        //      delegate void syncMainFuncCBDelegate(OutputFunction func);
        //      Parameter - func
        //	        main function changed during "Frequency Scanning"

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetFreqScanSine(bool OnOff, double startFreq, 
											     double stopFreq, int duration);
        //Parameter - startFreq:
	    //	value range: 0.67 ~ 500
	    //	unit: hertz
	    //	Default value after InitSECG(): 0.67Hz
	    //Parameter - stopFreq:
	    //	value range: 0.01 ~ 500
	    //	unit: hertz
	    //	Default value after InitSECG(): 150Hz
	    //Parameter - duration:
	    //	value range: 10 ~ 180
	    //	unit: milisecond(ms)
	    //	Default value after InitSECG(): 30ms
	    //Return value:
	    //	0: succeed
	    //	-1: SECG not be initialized
	    //	-2: startFreq out of range
	    //	-3: stopFreq out of range
	    //	-4: duration out of range
	    //"Output Function" would be set to "Output_Sine" when setting "OnOff" as true,
	    //then "Frequency" would be locked(SetFrequency() return -3) for periodly scanning change.
	    //"Output Function" would be set to "Output_Off" when setting "OnOff" as false.
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool GetFreqScanSine();
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetFreqScanSineStartFreq();
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern double GetFreqScanSineStopFreq();
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        public static extern int GetFreqScanSineDuration();
        public const double DefaultScanSineStartFreq = 0.67;
        public const double DefaultScanSineStopFreq = 150;
        public const int DefaultScanSineDuration = 30;

        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int SetFreqScanECG(bool OnOff);
        //Start Frequency as 3BPM(0.05Hz)
	    //Stop Frequency as 30BPM(0.5Hz)
	    //Duration as 30ms
	    //"Output Function" would be set to "Output_ECG2_27" when setting "OnOff" as true,
	    //then "Frequency" would be locked(SetFrequency() return -3) for periodly scanning change.
	    //"Output Function" would be set to "Output_Off" when setting "OnOff" as false.
        [DllImport(DllFilePath, CallingConvention = CallingConvention.Cdecl)]
        [return: MarshalAs(UnmanagedType.I1)]
        public static extern bool GetFreqScanECG();

        [DllImport(DllFilePath, CharSet = CharSet.Unicode, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int LoadECGtxt(string file);
        // >0: succeed, the number of sample data loaded
        // -1: Open file failed
        // -2: Can't solve sample rate in Line 1
        // -3: Can't solve sample number in Line 2
        // -4: Raw data file is too large to fit the memory

        [DllImport(DllFilePath, CharSet = CharSet.Unicode, CallingConvention = CallingConvention.Cdecl)]
	    public static extern int LoadECGbin(string file);
        // >0: succeed, the number of sample data loaded
        // -1: Open file failed
        // -2: Can't solve sample rate in Line 1
        // -3: Can't solve sample number in Line 2
        // -4: Raw data file is too large to fit the memory
    }
}
