﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
//using System.Linq;
using System.Text;
//using System.Threading.Tasks;
using System.Windows.Forms;
using WhaleTeqSECG_SDK;
using System.Runtime.InteropServices;    // For StructLayout, DllImport
using ZedGraph;
using System.Diagnostics;

namespace WhaleteqSECG_SDK_Demo
{
    public partial class WhaleteqSECG_SDK_UIDemo : Form
    {
        public delegate void ConnectCBDelegate(bool connected);

        private static ConnectCBDelegate fpConnect; //avoid CB be GC

        public delegate void TimeAmplitudeCBDelegate(double time, double amp);

        private static TimeAmplitudeCBDelegate fpTimeAmp; //avoid CB be GC
        private static TimeAmplitudeCBDelegate fpPacingTimeAmp; //avoid CB be GC

        public delegate void SyncFreqCBDelegate(double freq);

        private static SyncFreqCBDelegate fpSyncFreq; //avoid CB be GC

        public delegate void SyncMainFuncCBDelegate(OutputFunction mainFunc);

        private static SyncMainFuncCBDelegate fpSyncMainFunc; //avoid CB be GC

        private bool isSync = false;
        private bool ignoreSyncOff = false;
        public int Specialno = 1;

        private delegate void updateTitleCB(bool connected);
        private void UpdateTitle(bool connected)
        {
            if (!connected)
            {
                this.Text = "WhaleteqSECG_SDK_Demo           Can't initialize SECG!";
            }
            else
            {
                this.Text = "WhaleteqSECG_SDK_Demo           SN: ";

                IntPtr ptr;
                if (IntPtr.Zero != (ptr = SECG_SDK.GetHWInfo()))
                    this.Text += Marshal.PtrToStringAnsi(ptr);
                else
                    this.Text += SECG_SDK.GetSerialNo();
            }
        }

        private delegate void DelgConnectCB(bool connected);
        private void ConnectCB(bool connected)
        {
            if (InvokeRequired)
            {
                DelgConnectCB cb = new DelgConnectCB(ConnectCB);
                try
                {
                    Invoke(cb, connected);
                }
                catch { };
            }
            else
            {
                ResetDefaultValue_Click(null, null);
                UpdateTitle(connected);
            }
        }

        private void _initSECG()
        {
            fpConnect = new ConnectCBDelegate(ConnectCB);
            IntPtr ipConnect = Marshal.GetFunctionPointerForDelegate(fpConnect);
            SECG_SDK.RegistConnectCB(ipConnect);

            SECG_SDK.InitSECG();
        }

        public WhaleteqSECG_SDK_UIDemo()
        {
            InitializeComponent();
            AddGraphs();

            _initSECG();
#if false
            if (!SECG_SDK.InitSECG())
            {
                this.Text += "           Can't initialize SECG!";
            }
            else
            {
                this.Text += "           SN: ";

                IntPtr ptr;
                if (IntPtr.Zero != (ptr = SECG_SDK.GetHWInfo()))
                    this.Text += Marshal.PtrToStringAnsi(ptr);
                else
                    this.Text += SECG_SDK.GetSerialNo();
            }
#endif

            fpTimeAmp = new TimeAmplitudeCBDelegate(TimeAmplitudeCB);
            IntPtr ipTimeAmp = Marshal.GetFunctionPointerForDelegate(fpTimeAmp);

            SECG_SDK.RegisterTimeAmpCB(ipTimeAmp);

            fpPacingTimeAmp = new TimeAmplitudeCBDelegate(PacingTimeAmplitudeCB);
            IntPtr ipPacingTimeAmp = Marshal.GetFunctionPointerForDelegate(fpPacingTimeAmp);

            SECG_SDK.RegisterPacingTimeAmpCB(ipPacingTimeAmp);

            fpSyncFreq = new SyncFreqCBDelegate(SyncFreqCB);
            IntPtr ipSyncFreq = Marshal.GetFunctionPointerForDelegate(fpSyncFreq);

            SECG_SDK.RegisterSyncFreqCB(ipSyncFreq);

            fpSyncMainFunc = new SyncMainFuncCBDelegate(SyncMainFuncCB);
            IntPtr ipSyncMainFunc = Marshal.GetFunctionPointerForDelegate(fpSyncMainFunc);

            SECG_SDK.RegisterSyncMainFuncCB(ipSyncMainFunc);
        }

        private const int ZBufSize = 64;
        private double[] ZtgBuf = new double[ZBufSize];
        private double[] ZampBuf = new double[ZBufSize];
        private int ZBufIdx = 0;
        private double lastTg = 0;

        private void TimeAmplitudeCB(double time, double amp)
        {
            double tg = time - ((int)time / 5) * 5;

            if (ZBufIdx == ZBufSize || tg < lastTg)
            {
                if (Z.GraphPane.CurveList[0].NPts > 0 &&
                    ZtgBuf[0] < Z.GraphPane.CurveList[0].Points[Z.GraphPane.CurveList[0].NPts - 1].X)
                {
                    Z.GraphPane.CurveList[0].Clear();
                    Z.GraphPane.CurveList[1].Clear();
                }

                for (int i = 0; i < ZBufIdx; i++)
                    Z.GraphPane.CurveList[0].AddPoint(ZtgBuf[i], ZampBuf[i] + YS);

                for (int i = 0; i < ZBufIdxPacing; i++)
                    Z.GraphPane.CurveList[1].AddPoint(ZtgBufPacing[i], ZampBufPacing[i] + YS);

                ZBufIdx = 0;
                ZBufIdxPacing = 0;

                sNeedUpdateZ = true;
                sTime = time;
            }

            ZtgBuf[ZBufIdx] = tg;
            ZampBuf[ZBufIdx++] = amp;

            lastTg = tg;
        }

        private double[] ZtgBufPacing = new double[ZBufSize];
        private double[] ZampBufPacing = new double[ZBufSize];
        private int ZBufIdxPacing = 0;
        private void PacingTimeAmplitudeCB(double time, double amp)
        {
            double tg = time - ((int)time / 5) * 5;
            ZtgBufPacing[ZBufIdxPacing] = tg;
            ZampBufPacing[ZBufIdxPacing++] = amp;
        }

        private bool sNeedUpdateZ = false;
        private double sTime = 0;

        private void timer_updateGUI_Tick(object sender, EventArgs e)
        {
            if (sNeedUpdateZ)
            {
                Z.Invalidate();

                String timeStr = sTime.ToString("000.0") + "s";
                if (timeStr != timeTextBox.Text)
                    timeTextBox.Text = timeStr;

                sNeedUpdateZ = false;
            }
        }

        private ZedGraphControl Z = null;
        void AddGraphs()
        {
            Z = new ZedGraphControl();
            this.Controls.Add(Z);
            Z.Location = new Point(12, groupBox1.Bottom + 15);
            Z.Size = new Size(groupBox2.Left - 15, groupBox2.Bottom - groupBox1.Bottom - 15);
            Z.ScrollGrace = 0;
            Z.ScrollMaxX = 0;
            Z.ScrollMaxY = 0;
            Z.ScrollMaxY2 = 0;
            Z.ScrollMinX = 0;
            Z.ScrollMinY = 0;
            Z.ScrollMinY2 = 0;
            GraphPane GP = Z.GraphPane;
            LineItem M = GP.AddCurve("", new PointPairList(), Color.Blue, SymbolType.None);
            LineItem N = GP.AddCurve("", new PointPairList(), Color.DarkViolet, SymbolType.None);
            GP.Title.Text = "Output";
            GP.YAxis.Title.Text = "mV";
            GP.XAxis.Title.Text = "Time (s)";
            double XS = 5;
            Axis X = Z.GraphPane.XAxis;
            X.Scale.Max = XS;
            X.Scale.MajorStep = 1;
            X.Scale.MinorStep = 0.2;
            X.MinorGrid.IsVisible = true;
            X.MinorGrid.DashOff = 1;
            X.MinorGrid.DashOn = 5;
            X.MinorGrid.Color = Color.Pink;
            X.MajorGrid.IsVisible = true;
            X.MajorGrid.DashOff = 0;
            X.MajorGrid.DashOn = 10;
            X.MajorGrid.Color = Color.Pink;
            UpdateGraphScale(this, null);
        }

        public void ResetGraph()
        {
            Z.GraphPane.CurveList[0].Clear();
            Z.GraphPane.CurveList[1].Clear();
        }

        private double YS;
        void UpdateGraphScale(object O, EventArgs e)
        {
            Axis Y = Z.GraphPane.YAxis;
            YS = 2;                // 1mV for 10mm (10mm/mV)
            if (Graph4.Checked) YS = 5;   // 2mV for 10mm (5mm/mV)
            if (Graph20.Checked) YS = 1;  // 0.5mV for 10mm 
            Y.Scale.Max = 2 * YS;
            Y.Scale.Min = 0;
            Y.Scale.MajorStep = 1;
            Y.Scale.MinorStep = 0.5;
            Y.MinorGrid.IsVisible = true;
            Y.MajorGrid.IsVisible = true;
            Y.MinorGrid.Color = Color.Pink;
            Y.MajorGrid.Color = Color.Pink;
            Y.IsAxisSegmentVisible = false;
            Y.MinorGrid.DashOff = 1;
            Y.MinorGrid.DashOn = 5;
            Y.MajorGrid.DashOff = 0;
            Y.MajorGrid.DashOn = 10;
            ResetGraph();
            Z.Invalidate();
        }

        private void SyncFreqCB(double freq)
        {
            isSync = true;

            FreqHz.Value = (decimal)freq;           

            isSync = false;
        }

        private void SyncMainFuncCB(OutputFunction mainFunc)
        {
            if (mainFunc == OutputFunction.Output_Off)
            {
                if (ignoreSyncOff)
                    ignoreSyncOff = false;
                else
                    OutputOff.Checked = true;
                return;
            }

            isSync = true;

            switch (mainFunc)
            {
                case OutputFunction.Output_Sine:
                    OutputSine.Checked = true;
                    break;
                case OutputFunction.Output_Triangle:
                    OutputTriangle.Checked = true;
                    break;
                case OutputFunction.Output_Square:
                    OutputSquare.Checked = true;
                    break;
                case OutputFunction.Output_RectanglePulse:
                    OutputRectanglePulse.Checked = true;
                    break;
                case OutputFunction.Output_TrianglePulse:
                    OutputTrianglePulse.Checked = true;
                    break;
                case OutputFunction.Output_Exponential:
                    OutputExponential.Checked = true;
                    break;
                case OutputFunction.Output_ECG2_27:
                    OutputECG2_27.Checked = true;
                    break;
            }

            isSync = false;
        }



        private void WhaleteqSECG_SDK_Demo_FormClosed(object sender, FormClosedEventArgs e)
        {
            SECG_SDK.CloseSECG();
        }

        private void OutputOff_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton btn = (RadioButton)sender;

            if (!btn.Checked) return;

            if (isSync) return;

            SECG_SDK.SetOutputFunc(OutputFunction.Output_Off);

            FreqHz.Maximum = 500;
        }

        private void OutputSine_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton btn = (RadioButton)sender;
            if (!btn.Checked)
            {
                if (!BaselineOff.Checked)
                    BaselineOff.Checked = true;

                if (FreqScanSine.Checked)
                {
                    ignoreSyncOff = true;
                    FreqScanSine.Checked = false;
                }

                return;
            }

            if (isSync) return;
            
            SECG_SDK.SetOutputFunc(OutputFunction.Output_Sine);

            FreqHz.Maximum = 500;
        }

        private void OutputTirangle_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton btn = (RadioButton)sender;
            if (!btn.Checked) return;

            if (isSync) return;

            SECG_SDK.SetOutputFunc(OutputFunction.Output_Triangle);

            FreqHz.Maximum = 500;
        }

        private void OutputSquare_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton btn = (RadioButton)sender;
            if (!btn.Checked)
            {
                if (DynamicRange.Checked)
                    DynamicRange.Checked = false;
                return;
            }

            if (isSync) return;

            SECG_SDK.SetOutputFunc(OutputFunction.Output_Square);

            FreqHz.Maximum = 500;
        }

        private void OutputRectanglePulse_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton btn = (RadioButton)sender;
            if (!btn.Checked) return;

            if (isSync) return;

            SECG_SDK.SetOutputFunc(OutputFunction.Output_RectanglePulse);

            FreqHz.Maximum = 5;
        }

        private void OutputTrianglePulse_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton btn = (RadioButton)sender;
            if (!btn.Checked) return;

            if (isSync) return;

            SECG_SDK.SetOutputFunc(OutputFunction.Output_TrianglePulse);

            FreqHz.Maximum = 5;
        }

        private void OutputExponential_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton btn = (RadioButton)sender;
            if (!btn.Checked) return;

            if (isSync) return;

            SECG_SDK.SetOutputFunc(OutputFunction.Output_Exponential);

            FreqHz.Maximum = 3;
        }

        private void OutputECG2_27_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton btn = (RadioButton)sender;

            AAMIDriftTest.Enabled = btn.Checked;

            if (!btn.Checked)
            {
                if (!MainsNoiseOff.Checked)
                    MainsNoiseOff.Checked = true;

                if (FreqScanECG.Checked)
                {
                    ignoreSyncOff = true;
                    FreqScanECG.Checked = false;
                }

                return;
            }

            if (isSync) return;

            SECG_SDK.SetOutputFunc(OutputFunction.Output_ECG2_27);

            FreqHz.Maximum = 3;
        }
        private void Special_CheckedChanged(object sender , EventArgs e)
        {
            //RadioButton btn = (RadioButton)sender;
            RadioButton btn = radioButton2;

            if (Specialno == 0 || Specialno < 10)
            {
                if (!btn.Checked)
                    return;
                if (isSync)
                    return;
                SECG_SDK.SetSpecialWave227((SpecialWave227)(Specialno));
                //SECG_SDK.SetOutputFunc(OutputFunction.Output_IEC227W);                
            }
            else if (Specialno >= 10 && Specialno < 16)
            {
                if (!btn.Checked)
                    return;
                if (isSync)
                    return;
                SECG_SDK.SetSpecialWave251((SpecialWave251)(Specialno-10));
                //SECG_SDK.SetOutputFunc(OutputFunction.Output_IEC251W);  
            }
            else if (Specialno == 16)
            {
                if (!btn.Checked)
                    return;
                if (isSync)
                    return;
                SECG_SDK.SetOutputFunc(OutputFunction.Output_JJG_Hysteresis);
            }
            else if (Specialno == 17 || Specialno == 18)
            {
                if (!btn.Checked)
                    return;
                if (isSync)
                    return;
                SECG_SDK.SetOutputFunc(OutputFunction.Output_ECG_File);
            }
            else if (Specialno == 19)
            {
                if (!btn.Checked)
                    return;
                if (isSync)
                    return;
                SECG_SDK.SetOutputFunc(OutputFunction.Output_InputDynamicRange);
            }
        }
#if false
        public void Change227()
        {
            if (isSync)
                return;
             SECG_SDK.SetSpecialWave227((SpecialWave227)(Specialno));
             SECG_SDK.SetOutputFunc(OutputFunction.Output_IEC227W);
        }
        public void Change251()
        {
            if (isSync)
                return;
            SECG_SDK.SetSpecialWave251((SpecialWave251)(Specialno - 10));
            SECG_SDK.SetOutputFunc(OutputFunction.Output_IEC251W);
        }
#endif
        public void CheckSpecial()
        {
            if (radioButton2.Checked == false)
                radioButton2.Checked = true;
            else
                Special_CheckedChanged(radioButton2, null);
        }
        private void Amp_ValueChanged(object sender, EventArgs e)
        {
            NumericUpDown num = (NumericUpDown)sender;
            SECG_SDK.SetAmplitude((double)num.Value);
        }

        private void FreqHz_ValueChanged(object sender, EventArgs e)
        {
            FreqBPM.Value = FreqHz.Value * 60;

            if (!isSync)
            {
                if (0 != SECG_SDK.SetFrequency((double)FreqHz.Value))
                {
                    FreqHz.Value = (decimal)SECG_SDK.GetFrequency();
                    FreqBPM.Value = FreqHz.Value * 60;
                }
            }
        }

        private void FreqBPM_ValueChanged(object sender, EventArgs e)
        {
            FreqHz.Value = FreqBPM.Value / 60;
        }

        private void DCSetting_ValueChanged(object sender, EventArgs e)
        {
            NumericUpDown num = (NumericUpDown)sender;
            SECG_SDK.SetDCOffset((int)num.Value);
        }

        private void DCVariable_CheckedChanged(object sender, EventArgs e)
        {
            if (DCVariable.Checked)
            {
                DCSetting.Maximum = 1000;
                DCSetting.Minimum = -1000;
                DCSetting.Increment = 5;
                PacingAmp.Value = 0;
            }
            else
            {
                DCSetting.Maximum = 300;
                DCSetting.Minimum = -300;
                DCSetting.Increment = 300;
                DCSetting.Value = 0;
            }

            SECG_SDK.SetDCOffsetVariableMode(DCVariable.Checked);
        }

        private void DCCommon_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetDCOffsetCommoneMode(DCCommon.Checked);
        }

        private void PulseWidth_ValueChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetPulseWidth((double)PulseWidth.Value);
        }

        private void InputImpedance_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetInputImpedanceMode(InputImpedance.Checked);
        }

        private void PacingPulse_CheckedChanged(object sender, EventArgs e)
        {
            PacingPulse_E mode = PacingPulse_E.SinglePulse;
            if (PacingDouble150ms.Checked)
                mode = PacingPulse_E.DoublePulse_150ms;
            else if (PacingDouble250ms.Checked)
                mode = PacingPulse_E.DoublePulse_250ms;

            SECG_SDK.SetPacingPulseMode(mode);
        }

        private void QRSDuration_ValueChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetQRSDuration((double)QRSDuration.Value);
        }

        private void TWaveAmp_ValueChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetTWave((double)TWaveAmp.Value);
        }

        private void PacingAmp_ValueChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetPacingAmplitude((double)PacingAmp.Value);
        }

        private void PacingDuration_ValueChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetPacingDuration((double)PacingDuration.Value);
        }

        private void PacingRate_ValueChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetPacingRate((uint)PacingRate.Value);
        }

        private void PacingOvershootTC_ValueChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetOvershootTimeConstant((uint)PacingOvershootTC.Value);
        }

        private void LeadRA_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetOutputLead(OutputLead_E.Lead_RA, LeadRA.Checked);
        }

        private void LeadLA_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetOutputLead(OutputLead_E.Lead_LA, LeadLA.Checked);
        }

        private void LeadLL_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetOutputLead(OutputLead_E.Lead_LL, LeadLL.Checked);
        }

        private void LeadV1_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetOutputLead(OutputLead_E.Lead_V1, LeadV1.Checked);
        }

        private void LeadV2_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetOutputLead(OutputLead_E.Lead_V2, LeadV2.Checked);
        }

        private void LeadV3_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetOutputLead(OutputLead_E.Lead_V3, LeadV3.Checked);
        }

        private void LeadV4_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetOutputLead(OutputLead_E.Lead_V4, LeadV4.Checked);
        }

        private void LeadV5_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetOutputLead(OutputLead_E.Lead_V5, LeadV5.Checked);
        }

        private void LeadV6_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetOutputLead(OutputLead_E.Lead_V6, LeadV6.Checked);
        }

        private void Baseline_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton btn = (RadioButton)sender;
            if (!btn.Checked)
                return;

            BaselineReset_E mode = BaselineReset_E.Baseline_Off;
            if (btn == Baseline50Hz)
                mode = BaselineReset_E.Baseline_50Hz;
            else if (btn == Baseline60Hz)
                mode = BaselineReset_E.Baseline_60Hz;
            else if (btn == Baseline80Hz)
                mode = BaselineReset_E.Baseline_80Hz;
            else if (btn == Baseline100Hz)
                mode = BaselineReset_E.Baseline_100Hz;

            int RV = SECG_SDK.SetBaselineResetTest(mode);
            if (-2 == RV)
            {
                MessageBox.Show("Must have Main Function set to Sine function first for starting Baseline Reset Test");
                BaselineOff.Checked = true;
            }
        }

        private void MainsNoise_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton btn = (RadioButton)sender;
            if (!btn.Checked)
                return;

            ECG2_27_NoiseFreq_E mode = ECG2_27_NoiseFreq_E.Noise_None;
            if (btn == MainsNoise50Hz)
                mode = ECG2_27_NoiseFreq_E.Noise_50Hz;
            else if (btn == MainsNoise60Hz)
                mode = ECG2_27_NoiseFreq_E.Noise_60Hz;

            int RV = SECG_SDK.SetECG2_27_Noise(mode, (double)MainsNoiseAmp.Value);
            if (-2 == RV)
            {
                MessageBox.Show("Must have Main Function set to ECG2_27 function first for starting Mains Noise");
                MainsNoiseOff.Checked = true;
            }               
        }

        private void MainsNoiseAmp_ValueChanged(object sender, EventArgs e)
        {

            ECG2_27_NoiseFreq_E mode = ECG2_27_NoiseFreq_E.Noise_None;
            if (MainsNoise50Hz.Checked)
                mode = ECG2_27_NoiseFreq_E.Noise_50Hz;
            else if (MainsNoise60Hz.Checked)
                mode = ECG2_27_NoiseFreq_E.Noise_60Hz;

            SECG_SDK.SetECG2_27_Noise(mode, (double)MainsNoiseAmp.Value);
        }

        private void DynamicRange_CheckedChanged(object sender, EventArgs e)
        {
            int RV = SECG_SDK.SetDynamicRangeTest(DynamicRange.Checked,
                (double)DynamicRangeAmp.Value, (double)DynamicRangeFreq.Value);

            if (-2 == RV)
            {
                MessageBox.Show("Must have Main Function set to Square function first for starting Dynamic Range Test");
                DynamicRange.Checked = false;
            }

        }

        private void FreqScanSine_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetFreqScanSine(FreqScanSine.Checked, (double)FreqScanStart.Value,
                (double)FreqScanStop.Value, (int)FreqScanDuration.Value);
        }

        private void FreqScanECG_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetFreqScanECG(FreqScanECG.Checked);
        }

        private void ResetDefaultValue_Click(object sender, EventArgs e)
        {
            if (SECG_SDK.GetOutputFunc() != OutputFunction.Output_Off)
                OutputOff.Checked = true;

            if (SECG_SDK.GetAmplitude() != SECG_SDK.DefaultAmplitude)
                Amp.Value = (decimal)SECG_SDK.DefaultAmplitude;

            if (SECG_SDK.GetFrequency() != SECG_SDK.DefaultFrequency)
                FreqHz.Value = (decimal)SECG_SDK.DefaultFrequency;

            if (SECG_SDK.GetDCOffset() != SECG_SDK.DefaultDCOffset)
                DCSetting.Value = (decimal)SECG_SDK.DefaultDCOffset;

            if (SECG_SDK.GetDCOffsetVariableMode())
                DCVariable.Checked = false;

            if (SECG_SDK.GetDCOffsetCommoneMode())
                DCCommon.Checked = false;

            if (SECG_SDK.GetPulseWidth() != SECG_SDK.DefaultPulseWidth)
                PulseWidth.Value = (decimal)SECG_SDK.DefaultPulseWidth;

            if (!SECG_SDK.GetInputImpedanceMode())
                InputImpedance.Checked = true;

            if (SECG_SDK.GetPacingPulseMode() != PacingPulse_E.SinglePulse)
                PacingSinglePulse.Checked = true;

            if (SECG_SDK.GetQRSDuration() != SECG_SDK.DefaultQRSDuration)
                QRSDuration.Value = (decimal)SECG_SDK.DefaultQRSDuration;

            if (SECG_SDK.GetTWave() != SECG_SDK.DefaultTWave)
                TWaveAmp.Value = (decimal)SECG_SDK.DefaultTWave;

            if (SECG_SDK.GetPacingAmplitude() != SECG_SDK.DefaultPacingAmplitude)
                PacingAmp.Value = (decimal)SECG_SDK.DefaultPacingAmplitude;

            if (SECG_SDK.GetPacingDuration() != SECG_SDK.DefaultPacingDuration)
                PacingDuration.Value = (decimal)SECG_SDK.DefaultPacingDuration;

            if (SECG_SDK.GetPacingRate() != SECG_SDK.DefaultPacingRate)
                PacingRate.Value = (decimal)SECG_SDK.DefaultPacingRate;

            if (SECG_SDK.GetOvershootTimeConstant() != SECG_SDK.DefaultOvershootTimeConstant)
                PacingOvershootTC.Value = (decimal)SECG_SDK.DefaultOvershootTimeConstant;

            if (!SECG_SDK.GetOutputLead(OutputLead_E.Lead_RA))
                LeadRA.Checked = true;
            if (SECG_SDK.GetOutputLead(OutputLead_E.Lead_LA))
                LeadLA.Checked = false;
            if (SECG_SDK.GetOutputLead(OutputLead_E.Lead_LL))
                LeadLL.Checked = false;
            if (SECG_SDK.GetOutputLead(OutputLead_E.Lead_V1))
                LeadV1.Checked = false;
            if (SECG_SDK.GetOutputLead(OutputLead_E.Lead_V2))
                LeadV2.Checked = false;
            if (SECG_SDK.GetOutputLead(OutputLead_E.Lead_V3))
                LeadV3.Checked = false;
            if (SECG_SDK.GetOutputLead(OutputLead_E.Lead_V4))
                LeadV4.Checked = false;
            if (SECG_SDK.GetOutputLead(OutputLead_E.Lead_V5))
                LeadV5.Checked = false;
            if (SECG_SDK.GetOutputLead(OutputLead_E.Lead_V6))
                LeadV6.Checked = false;

            if (SECG_SDK.GetECG2_27_NoiseAmp() != SECG_SDK.DefaultECG2_27_NoiseAmp)
                MainsNoiseAmp.Value = (decimal)SECG_SDK.DefaultECG2_27_NoiseAmp;

            if (SECG_SDK.GetDynamicRangeTestAmp() != SECG_SDK.DefaultDynamicRangeTestAmp)
                DynamicRangeAmp.Value = (decimal)SECG_SDK.DefaultDynamicRangeTestAmp;
            if (SECG_SDK.GetDynamicRangeTestFreq() != SECG_SDK.DefaultDynamicRangeTestFreq)
                DynamicRangeFreq.Value = (decimal)SECG_SDK.DefaultDynamicRangeTestFreq;

            if (SECG_SDK.GetFreqScanSineStartFreq() != SECG_SDK.DefaultScanSineStartFreq)
                FreqScanStart.Value = (decimal)SECG_SDK.DefaultScanSineStartFreq;
            if (SECG_SDK.GetFreqScanSineStopFreq() != SECG_SDK.DefaultScanSineStopFreq)
                FreqScanStop.Value = (decimal)SECG_SDK.DefaultScanSineStopFreq;
            if (SECG_SDK.GetFreqScanSineDuration() != SECG_SDK.DefaultScanSineDuration)
                FreqScanDuration.Value = (decimal)SECG_SDK.DefaultScanSineDuration;

            ResetGraph();
            Z.Invalidate();
            Specialno = 0;

            timeTextBox.Text = "000.0s";

#if true
            SECG_SDK.ResetSECG();
#else
            SECG_SDK.CloseSECG();
            this.Text = "WhaleteqSECG_SDK_Demo";
            _initSECG();
#endif
        }

        //added for special waveforms
        private void Special_click(object sender, EventArgs e)
        {
            SpecialWaveForm SW = new SpecialWaveForm();
            SW.demo = this;
            SW.ShowDialog(this);
            SW.Close();
        }

        private void AAMIDriftTest_CheckedChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetECG2_27_AAMIDriftTest(AAMIDriftTest.Checked);
        }

        private void OvershootAmp_ValueChanged(object sender, EventArgs e)
        {
            SECG_SDK.SetPacingOvershootAmp((double)OvershootAmp.Value);
        }
    }
}
